@@ -21,7 +21,8 @@ def randstr(n):
     return ''.join(map(chr, map(random.randrange, [0]*n, [256]*n)))
 
 KEYSIZE=192 # The choices are 192 or 521 -- they are both secure, and 192 makes for faster unit tests.
-class Signer(unittest.TestCase):
+# class Signer(unittest.TestCase):
+class Signer(): # ecdsa disabled for now
     def test_generate_bad_size(self):
         try:
             signer = ecdsa.generate(KEYSIZE-1)
@@ -48,7 +49,8 @@ class Signer(unittest.TestCase):
         self.failUnlessEqual(len(result), 2*((KEYSIZE+7)/8))
         # TODO: test against someone's official test vectors.
 
-class SignAndVerify(unittest.TestCase):
+# class SignAndVerify(unittest.TestCase):
+class SignAndVerify(): # ecdsa disabled for now
     def _help_test_sign_and_check(self, signer, verifier, msg):
         sig = signer.sign(msg)
         self.failUnlessEqual(len(sig), 2*((KEYSIZE+7)/8))
